from distutils.core import setup
setup(
    name='xkwpy',
    version='1.0.0',
    description='just for test',
    author='royalxkw',
    url='https://github.com',
    author_email='284440954@qq.com',
)
